@@ -1,4 +1,4 @@
-from .mas_c import compute_mas_alignement
+from aligner_pytorch.mas_c import compute_mas_alignement
 import torch 
 from torch import Tensor 
 from typing import Optional 
